#
# spec file for package phonon4qt5
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define rname phonon

Name:           phonon4qt5
Version:        4.9.0
Release:        2.6
Summary:        Multimedia Platform Abstraction
License:        LGPL-2.0+
Group:          System/GUI/KDE
Url:            http://phonon.kde.org/
Source:         http://download.kde.org/stable/%{rname}/%{version}/%{rname}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules >= 1.7.0
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  libpulse-devel
BuildRequires:  xz
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glib-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Phonon is a cross-platform portable multimedia support abstraction,
which allows you to play multiple audio or video formats with the same
quality on all platforms, no matter which underlying architecture is
used.

%package devel
Summary:        Phonon Multimedia Platform Abstraction
Group:          Development/Libraries/KDE
Requires:       libphonon4qt5 = %{version}
Requires:       extra-cmake-modules >= 1.7.0

%description devel
Phonon is a cross-platform portable Multimedia Support Abstraction,
which allows you to play multiple audio or video formats with the same
quality on all platforms, no matter which underlying architecture is
used.

%package -n libphonon4qt5
Summary:        Phonon Multimedia Platform Abstraction
Group:          System/Libraries
Recommends:     phonon4qt5-backend

%description -n libphonon4qt5
Phonon is a cross-platform portable Multimedia Support Abstraction,
which allows you to play multiple audio or video formats with the same
quality on all platforms, no matter which underlying architecture is
used.

%prep
%setup -q -n %{rname}-%{version}

%build
  %cmake_kf5 -d build -- -DPHONON_BUILD_PHONON4QT5=ON -DPHONON_INSTALL_QT_EXTENSIONS_INTO_SYSTEM_QT=true -DDBUS_INTERFACES_INSTALL_DIR=%{_kf5_sharedir}/dbus-1/interfaces/
  %make_jobs

%install
  %kf5_makeinstall -C build
  %fdupes -s %{buildroot}%{_includedir}/%{name}

%post   -n libphonon4qt5 -p /sbin/ldconfig

%postun -n libphonon4qt5 -p /sbin/ldconfig

%files -n libphonon4qt5
%defattr(-,root,root)
%{_kf5_libdir}/lib%{name}.so.*
%{_kf5_libdir}/lib%{name}experimental.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_kf5_libdir}/cmake/%{name}
%{_kf5_sharedir}/%{name}
%{_kf5_libdir}/pkgconfig/%{name}.pc
%{_kf5_libdir}/lib%{name}experimental.so
%{_kf5_libdir}/lib%{name}.so
%{_libqt5_archdatadir}/mkspecs/modules/qt_phonon4qt5.pri
%{_libqt5_plugindir}/designer/phononwidgets.so
%{_kf5_sharedir}/dbus-1/interfaces/org.kde.Phonon4Qt5.AudioOutput.xml

%changelog
* Sat Jun 11 2016 hrvoje.senjan@gmail.com
- Drop BuildRequires on obsolete QtQuick1 module
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 4.9.0
  * Changes
  * Builsystem helpers are now installed to CMAKE_INSTALL_DATAROOTDIR
  * CMake 2.8.9 is required to use GNUInstallDirs and for the Qt5
    code branches
  * automoc4 support was removed. Building always use the cmake
    built-in solution now.
  * Qt5 and Qt4 builds use different CMake configurations now
    Qt4 is as it always has been
  * Qt5 moved away from crudely ported Qt4 configurations to using
    extra-cmake-modules' KDE compiler and cmake flags.
  * Installation paths and so forth are still jointly configured as
    to retain backwards compatibility (i.e. Qt5 build does not
    follow ECM's KDEInstallationPaths)
  * Bug Fixes
  * VolumeSlider has seen async behavior improvements making the
    slider not hop around when changing the volume rapidly and
    the backend is lagging a bit behind.
  * The volume change now occurs upon slider release rather
    than instantly.
  * Fixed a duble encoding issue with local paths that contain
    percent encoded characters being double-encoded [kde#356218]
  * New API
  * New AudioOutputInterface49 for backends to implement. This
    interface implements long-existing frontend interfaces for
    muting, giving the backend easier access and control.
  * setMuted(bool) mutes an AudioOuput (without the 4.9
    interface this is done via setVolume(0.0) on the backend)
  * mutedChanged(bool) signal emitted by the backend to
    asyncronuously notify of the mute application
  * The interface is only used if PulseSupport is not
    intercepting calls
  * New methods to differntiate states of PulseSupport
  * request(bool) is used by backends to request PulseAudio
    usage but no interception, this essentially enables device
    listing but lets everything else fall through to the backend
    (the existing isActive() method will not return true after
    request(true), which makes it different from enable(true))
  * isRequested() is a getter for request()'s state
  * isUsable() is part of the previouys isActive() behavior,
    it is true iff pulseaudio can be used
    (daemon running, connected etc)
  * isUsed() is a combination of isRequested() and isUsable()
    (i.e. active but not intercepting)
  * The existing isActive() communicates the same state as
    before (active and intercepting) but now also takes
    requested into consideration
  * Enabling always implies requsting automatically, so
    request(false) and enable(true) will ultimately still
    restul in isRequested==true
- Drop upstreamed 0001-tear-cmake-logic-for-qt4-and-qt5-apart.patch
* Sat Jul 11 2015 hrvoje.senjan@gmail.com
- Added 0001-tear-cmake-logic-for-qt4-and-qt5-apart.patch from
  upstream, to handle better -fPIC flag in Qt 5 builds
- Drop pic.patch
- Added extra-cmake-modules >= 1.7.0 (Build)Requires, needed with
  the added patch
* Thu May 21 2015 hrvoje.senjan@gmail.com
- Added pic.patch, fix build with latest Qt5 - it now requires -fPIC
  flag instead of -fPIE when Qt is built with reduced-relocations
  option
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 4.8.3:
  * Set target interface include install dir
  * Do not assume we have a backend when setting an output device,
    kde#341296
* Wed Nov  5 2014 hrvoje.senjan@gmail.com
- Update to 4.8.2:
  * Revised the logic used by PulseSupport to come up with an icon
    name for PulseAudio. If the application has
    QApplication::windowIcon set with an QIcon constructed through
    QIcon::fromTheme(string) the actual icon name will be used.
    Otherwise the lower-case version of
    QCoreApplication::applicationName is used.
  * Fixed building with the compiler clang by reverting
    a previously introduced workaround.
- Fix Requires of devel package, there was a wrong "BuildRequires",
  and they shall be found by pkg-config detection
* Sun Oct 19 2014 hrvoje.senjan@gmail.com
- Update to 4.8.1:
  * Version bump
  * Prevent a crash when failing to create the preferred backend
* Tue Aug 12 2014 hrvoje.senjan@gmail.com
- Update to 4.7.80
  * 4.8 beta: PA interaction improvements, documentation fixes and
    standard bugfixes
* Fri Jun 20 2014 hrvoje.senjan@gmail.com
- Update to 4.7.2
  * Bugfix release, no changelog provided
* Tue Jun  3 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Adjust filelists to kf5-filesystem changes
* Fri Feb 21 2014 hrvoje.senjan@gmail.com
- Remove baselibs.conf, until baselibs for libqt5-qttools are
  provided
* Thu Feb 20 2014 hrvoje.senjan@gmail.com
- Move to kf5-filesystem, instead of kde4 one
- Only BuildRequire those libraries which are needed
- Adjust baselibs.conf to reality
* Fri Dec  6 2013 hrvoje.senjan@gmail.com
- Update to 4.7.1
  * Fixed compatibility issues with older backend versions
- Move away from pkgconfig(...) BuildRequires and just use
  libqt5-$upstreammodulename-(devel|private-headers-devel)
* Wed Nov 27 2013 hrvoje.senjan@gmail.com
- Build phonon4qt5 package
- Remove obsolete, and not needed 'ready' file
- Remove not needed automoc4 BuildRequires
* Mon Nov  4 2013 hrvoje.senjan@gmail.com
- Update to official 4.7.0 release
  * Minor documentation fixes since last update
- Add Source URL
* Mon Nov  4 2013 hrvoje.senjan@gmail.com
- Update to 4.7.0~git20131104
  * Buildsystem fixes since previous snapshot
  * Version bump to 4.7.0
* Mon Sep 30 2013 hrvoje.senjan@gmail.com
- Update to 4.6.80~git20130930
  * Add preference system ontop of Qt5 backend loading
  * Unbreak documentation of AO47
  * Don't crash when trying to create the singleton out of a
    qapp parented AO (kde#293004)
* Tue Sep 24 2013 hrvoje.senjan@gmail.com
- Drop 0001-Revert-cache-volume-inside-PAStreams-when-trying-to-.patch
  better solution is done in kdebase4-runtime package
* Tue Sep 17 2013 hrvoje.senjan@gmail.com
- Added 0001-Revert-cache-volume-inside-PAStreams-when-trying-to-.patch,
  which resolves a regression in volume getting restored after each
  knotify event (kde#324975)
* Sun Sep 15 2013 hrvoje.senjan@gmail.com
- Update to 4.6.80~git20130915
  * Snapshot of soon to be released 4.7 version
  * Various improvements, bugfixes, API aditions, documentation fixes
  * Qt5 support
- Drop phonon-4.6.0-find-backends-outside-of-kde-session.diff
* Tue May 14 2013 dev@dominik-schmidt.de
- Add phonon-4.6.0-find-backends-outside-of-kde-session.diff:
  Fixes loading of plugins outside of KDE sessions although the
  plugins are installed in the KDE dir
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sun Nov 25 2012 cgiboudeaux@gmx.com
- Fix the SLES build (%%make_install doesn't exist)
* Mon Jun 25 2012 wstephenson@suse.com
- Remove optional Zeitgeist integration due to its creating very
  long build chain dependencies.
* Tue Feb  7 2012 idonmez@suse.com
- Revert adding libQtWebKit-devel dependency, QtZeitgeist devel
  package now requires it.
* Wed Feb  1 2012 idonmez@suse.com
- Add libQtWebKit-devel dependency needed due to QtZeitgeist
* Sun Jan  1 2012 cgiboudeaux@gmx.com
- Update to 4.6.0
  * Require QZeitgeist 0.8
  * Various buildsystem fixes
  * Improve the PulseAudio support
  * Fix some deadlocks
  * relicense to LGPL
* Mon Oct 31 2011 fisiu@opensuse.org
- Update to 4.5.1:
  + Runtime backend switching has been removed
  + A number of threading fixes with KIO/QIODevice streaming
  + Fixes to PulseAudio device enumeration
  + Proper Qt only library without any KDE references
  + DBus is optional now
- Drop phonon-math-include.patch: fixed upstream.
* Fri Oct 21 2011 wstephenson@suse.com
- Remove the PulseAudio 1.0 detection fix, superseded by PA 1.1
* Fri Oct  7 2011 toddrme2178@gmail.com
- Cleaned up spec file formatting
* Thu Sep 29 2011 idonmez@suse.com
- Fix detection of PulseAudio 1.0
* Sun Sep 25 2011 javier@opensuse.org
- Fix obsoletes for KDE:Release:46/phonon
* Tue Aug 30 2011 idonmez@suse.com
- Add phonon-math-include.patch, add missing math.h include
* Thu Aug 11 2011 toddrme2178@gmail.com
- Added qtzeitgeist buildrequires
- Moved contents of phonon package to libphonon
  It only included some directories and some dbus stuff
- Cleaned up spec file formatting
* Tue Mar 29 2011 tittiatcoke@gmail.com
- update to 4.5.0
  * comes with all new Zeitgeist support, which enables multimedia
  applications to let Zeitgeist log playback activity to further
  improve the semantic desktop capabilities of both the KDE Software
  Collection as well as GNOME.
  * Also new is integration with Qt Designer
  * many smaller improvements to increase reliability of both
    Phonon itself as well as its backends
* Thu Jan 13 2011 toddrme2178@gmail.com
- update to 4.4.4
- split off xine and gstreamer backends to their own packages
* Thu Nov 25 2010 dmueller@suse.de
- update to 4.4.3:
  * final release tarball
  * small gstreamer backend fixes
  * ABI fix in experimental API
* Tue Aug 17 2010 tittiatcoke@gmail.com
- update to a newer snapshot of 4.4.3
  * Set device access list for pulse devices
  * Introduce Phonon::DeviceAccessList from the KDE Platform plugin
  * Experimental feature: AVCapture
* Mon Jul 19 2010 tittiatcoke@gmail.com
- Update to a newer snapshot of 4.4.3
* Mon Jun  7 2010 dmueller@suse.de
- update to 4.4.2:
  * merged the diff to master into the version
* Tue May 11 2010 dmueller@suse.de
- add diff to current master to fix pulseaudio regression (bnc#604046)
* Wed May  5 2010 dmueller@suse.de
- update to 4.4.1:
  * merged symbian fixes
  * improved pulseaudio support
* Fri Mar 26 2010 tittiatcoke@gmail.com
- Added a patch (upstream/Colin Cuthrie) to prevent an endless loop
  when pulseaudio is not installed
* Wed Mar 24 2010 per@osbeck.com
- add BuildRequires for proper pulseaudio support
* Mon Mar 15 2010 dmueller@suse.de
- update to 4.4.0:
  * bugfixes
  * improved video recording/playback
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  + one header bugfix compared to previous update
* Mon Nov 23 2009 tittiatcoke@gmail.com
- updated to svn1052215
  + add the 'file://' scheme to urls that don't have it, so
    gstreamer doesn't complain on pathnames with characters that
    get percent-endoded.
  + make the xine backend work with local files with filenames
    wrongly encoded/with mixed encodings.
  + Add initial support for DVD Support
  + [Gstreamer] Fix changing audio track
  + Xine has equalizer functionality which is used in Amarok
* Tue Oct 20 2009 adrian@suse.de
- split plugins away in own spec file, this avoids build triggers
  from gnome or xine framework to entire KDE
- minor spec file cleanup (remove support of outdated distros)
* Wed May 13 2009 dmueller@suse.de
- add versioned dependencies
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.3.1:
  * sync with the version in Qt 4.5.0, various bugfixes
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.3.0:
  * Qt 4.5 fixes
  * fix volume handling / volume fader
* Mon Jan 12 2009 dmueller@suse.de
- update to 4.2.96:
  * new phonon backend without KDE dependencies
  * other improvements necessary for KDE 4.2
* Fri Jan  9 2009 llunak@suse.cz
- patch for ogg support (bnc#438718)
* Tue Oct 21 2008 dmueller@suse.de
- add versioned requires on libphonon4
* Wed Sep 10 2008 dmueller@suse.de
- fix build for older distros
* Tue Jul 22 2008 dmueller@suse.de
- update to 4.2.0:
  * bugfixes
* Thu Jul  3 2008 aj@suse.de
- Add baselibs.conf for libphonon.
* Thu Jul  3 2008 dmueller@suse.de
- enable gstreamer-010 based backend
* Fri Jun 20 2008 dmueller@suse.de
- update to 4.1.83:
  * more bugfixes, reworked audio device handling
* Tue May 27 2008 dmueller@suse.de
- Initial package (4.1.81)
